pub type LockToken = Id<LockTokenTag>;Expand description
A unique token identifying a single acquisition of a lock. Used as a fencing token so a release only frees the acquisition that created it.
Aliased Type
pub struct LockToken { /* private fields */ }